@@ -28,6 +28,8 @@
 
 #include "glpset.h"
 
+#define aat_numb              glp_aat_numb
+#define aat_symb              glp_aat_symb
 #define check_mat             glp_check_mat
 #define check_per             glp_check_per
 #define clear_line            glp_clear_line
@@ -47,11 +49,14 @@
 #define lt_solve              glp_lt_solve
 #define mat_per               glp_mat_per
 #define mat_vec               glp_mat_vec
+#define mprd_numb             glp_mprd_numb
+#define mprd_symb             glp_mprd_symb
 #define new_elem              glp_new_elem
 #define per_mat               glp_per_mat
 #define per_vec               glp_per_vec
 #define reset_per             glp_reset_per
 #define scrape_mat            glp_scrape_mat
+#define show_mat              glp_show_mat
 #define sort_mat              glp_sort_mat
 #define submatrix             glp_submatrix
 #define test_mat_d            glp_test_mat_d
@@ -111,6 +116,12 @@ struct PER
          not used) */
 };
 
+extern MAT *aat_numb(MAT *S, MAT *A, double D[], double work[]);
+/* compute matrix product S = A * D * A'; numeric phase */
+
+extern MAT *aat_symb(MAT *S, MAT *A, char work[]);
+/* compute matrix product S = A * A'; symbolic phase */
+
 extern void check_mat(MAT *A);
 /* check sparse matrix for correctness */
 
@@ -169,6 +180,12 @@ extern MAT *mat_per(MAT *A, PER *P, void *work[]);
 extern double *mat_vec(double y[], MAT *A, double x[]);
 /* multiply matrix on vector (y := A * x) */
 
+extern MAT *mprd_numb(MAT *C, MAT *A, MAT *B, double _work[]);
+/* multiply matrices (C := A * B); numeric phase */
+
+extern MAT *mprd_symb(MAT *C, MAT *A, MAT *B, char work[]);
+/* multiply matrices (C := A * B); symbolic phase */
+
 extern ELEM *new_elem(MAT *A, int i, int j, double val);
 /* create new element of matrix */
 
@@ -184,6 +201,9 @@ extern PER *reset_per(PER *P);
 extern int scrape_mat(MAT *A, double eps);
 /* remove tiny elements from sparse matrix */
 
+extern int show_mat(MAT *A, int type, char *fname);
+/* output matrix pattern as raster image */
+
 extern MAT *sort_mat(MAT *A);
 /* ordering row and column lists of sparse matrix */
 
